#include "uiinspector.h"
#include "ui_uiinspector.h"

UiInspector::UiInspector(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::UiInspector) {
    ui->setupUi(this);

    ui->splitter_2->setStretchFactor(0, 1);
    ui->splitter_2->setStretchFactor(1, 2);

    render = 0;
    triggerItem = new QTreeWidgetItem(ui->ccView, QStringList() << "");
    triggerItem->setFlags(Qt::ItemIsEnabled);
    curveItem = new QTreeWidgetItem(ui->ccView, QStringList() << "");
    curveItem->setFlags(Qt::ItemIsEnabled);
    cursorItem = new QTreeWidgetItem(ui->ccView, QStringList() << "");
    cursorItem->setFlags(Qt::ItemIsEnabled);

    ui->ccView->expandAll();

    ui->colorCombo1->clear();
    ui->colorCombo2->clear();
    ui->colorCombo3->clear();
    ui->colorCombo4->clear();

    actionInfoLock = true;
    needRefresh = true;
    startTimer(100);

    refresh();
}

UiInspector::~UiInspector() {
    delete ui;
}

void UiInspector::changeEvent(QEvent *e) {
    QWidget::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

QTreeWidget* UiInspector::getViewGroup() const {
    return ui->viewGroupCheckList;
}
qreal UiInspector::getViewZStart() const {
    return ui->viewZStartSpin->value();
}
qreal UiInspector::getViewZEnd() const {
    return ui->viewZEndSpin->value();
}

QTreeWidget* UiInspector::getProjectFiles() const {
    return ui->projectFiles;
}
QTreeWidget* UiInspector::getProjectScripts() const {
    return ui->projectScripts;
}


void UiInspector::actionInfo() {
    if(!actionInfoLock) {
        foreach(NxObject *object, *(render->getSelection())) {
            if(ui->IDSpin == sender())
                object->setId(ui->IDSpin->value());
            else if(ui->positionX == sender())
                object->setPos(QPointF(ui->positionX->value(), object->getPos().y()));
            else if(ui->positionY == sender())
                object->setPos(QPointF(object->getPos().x(), ui->positionY->value()));
            else if(ui->positionZ == sender())
                object->setZ(ui->positionZ->value());
            else if(ui->activityCheck == sender())
                object->setActive(ui->activityCheck->isChecked());
            else if(ui->labelLine == sender())
                object->setLabel(ui->labelLine->text());
            else if(ui->sizeSpin == sender())
                object->setSize(ui->sizeSpin->value());

            if(object->getType() == ObjectsTypeCursor) {
                NxCursor *cursor = (NxCursor*)object;
                if(ui->widthSpin == sender())
                    cursor->setWidth(ui->widthSpin->value());
                else if(ui->speedFSpin == sender())
                    cursor->setTimeFactorF(ui->speedFSpin->value());
                else if(ui->posSpin == sender())
                    cursor->setTimeLocal(ui->posSpin->value());
                else if(ui->patternLine == sender())
                    cursor->setStart(ui->patternLine->text());
                else if(ui->speedSpin == sender())
                    cursor->setTimeFactor(ui->speedSpin->value());
                else if(ui->cursorLengthSpin == sender())
                    cursor->setTimeFactor(cursor->getCurve()->getPathLength() / ui->cursorLengthSpin->value());
                else if(ui->offsetInitialSpin == sender())
                    cursor->setTimeInitialOffset(ui->offsetInitialSpin->value());
                else if(ui->offsetStartSpin == sender())
                    cursor->setTimeStartOffset(ui->offsetStartSpin->value());
                else if(ui->offsetEndSpin == sender())
                    cursor->setTimeEndOffset(ui->offsetEndSpin->value());
                else if(ui->cursorBoundsLine1 == sender())
                    cursor->setBoundsSource(ui->cursorBoundsLine1->text());
                else if(ui->cursorBoundsLine2 == sender())
                    cursor->setBoundsTarget(ui->cursorBoundsLine2->text());
            }
            else if(object->getType() == ObjectsTypeCurve) {
                NxCurve *curve = (NxCurve*)object;
                if(ui->sizeWSpin == sender())
                    curve->setResize(QSizeF(ui->sizeWSpin->value(), curve->getResize().height()));
                else if(ui->sizeHSpin == sender())
                    curve->setResize(QSizeF(curve->getResize().width(), ui->sizeHSpin->value()));
            }
            else if(object->getType() == ObjectsTypeTrigger) {
                NxTrigger *trigger = (NxTrigger*)object;
                if(ui->triggerOffSpin == sender())
                    trigger->setTriggerOff(ui->triggerOffSpin->value());
            }
        }
        refresh();
    }
}
void UiInspector::actionColor() {
    if(!actionInfoLock) {
        QComboBox *combo = (QComboBox*)sender();
        QString val = combo->currentText();
        QStringList oldValStr = combo->currentText().split(" ", QString::SkipEmptyParts);
        if((combo->currentText() == "Custom") || (oldValStr.count() == 4)) {
            QColor oldVal = Qt::white;
            if(oldValStr.count() == 4)
                oldVal = QColor(oldValStr[0].toUInt(), oldValStr[1].toUInt(), oldValStr[2].toUInt(), oldValStr[3].toUInt());
            QColor valColor = QColorDialog::getColor(oldVal, 0, tr("IanniX Color Inspector"), QColorDialog::ShowAlphaChannel);
            val = QString("%1 %2 %3 %4").arg(valColor.red()).arg(valColor.green()).arg(valColor.blue()).arg(valColor.alpha());
        }
        foreach(NxObject *object, *(render->getSelection())) {
            if(ui->colorCombo1 == sender())
                object->setColorActive(val);
            else if(ui->colorCombo2 == sender())
                object->setColorInactive(val);
            else if(object->getType() == ObjectsTypeTrigger) {
                NxTrigger *trigger = (NxTrigger*)object;
                if(ui->colorCombo3 == sender())
                    trigger->setColorActiveMessage(val);
                else if(ui->colorCombo4 == sender())
                    trigger->setColorInactiveMessage(val);
            }
        }
        /*
        QStringList oldValStr = combo.split(" ", QString::SkipEmptyParts);
        if(oldValStr.count() == 4) {
            QColor oldVal(oldValStr[0].toUInt(), oldValStr[1].toUInt(), oldValStr[2].toUInt(), oldValStr[3].toUInt());
            QColor val = QColorDialog::getColor(oldVal, 0, tr("IanniX Color Inspector"), QColorDialog::ShowAlphaChannel);
        }
        */
        refresh();
    }
}

void UiInspector::actionNetwork() {
    if(ui->oscInPortSpin == sender()) {
        ui->oscInPortSpin->setStyleSheet("");
        emit(oscPortChange(ui->oscInPortSpin->value()));
    }
    else if(ui->udpInPortSpin == sender()) {
        ui->udpInPortSpin->setStyleSheet("");
        emit(udpPortChange(ui->udpInPortSpin->value()));
    }
    else if(ui->serialInPortEdit == sender()) {
        ui->serialInPortEdit->setStyleSheet("");
        emit(serialPortChange(ui->serialInPortEdit->text()));
    }
}


void UiInspector::actionInfoGroup() {
    bool ok = false;
    QString groupeId = QInputDialog::getText(0, tr("IanniX Inspector"), tr("New group name"), QLineEdit::Normal, ui->groupIdButton->text().remove(tr(" (change)")), &ok);
    if(ok) {
        foreach(NxObject *object, *(render->getSelection()))
            object->setGroupId(groupeId);
        needRefresh = true;
    }
}
void UiInspector::actionMessages() {
    if(render->getSelection()->count()) {
        ExtOscPatternAsk *ask = new ExtOscPatternAsk(0, render->getSelection());
        if(!ask->onlyCurves) {
            ask->exec();
            foreach(NxObject *object, *(render->getSelection()))
                object->setMessagePatterns(ask->getMessagePatterns());
        }
    }
}

void UiInspector::logOscSend(const QString & message) {
    ui->oscSendText->appendPlainText(message);
}
void UiInspector::logOscReceive(const QString & message) {
    ui->oscReceiveText->appendPlainText(message);
}
void UiInspector::setMousePos(const QPointF & pos) {
    ui->mouseLabel->setText(tr("Mouse") + " : " + QString().setNum(pos.x(), 'f', 3) + " / " + QString().setNum(pos.y(), 'f', 3));
}
void UiInspector::setMouseZoom(qreal zoom) {
    ui->zoomLabel->setText(tr("Zoom") + " : " + QString().setNum(zoom, 'f', 0) + "%");
}

void UiInspector::timerEvent(QTimerEvent *) {
    if(needRefresh)
        refresh();
}
void UiInspector::refresh() {
    QString triggerStr = tr("Triggers") + " (" + QString().setNum(triggerItem->childCount()) + ")";
    QString cursorStr = tr("Cursors") + " (" + QString().setNum(cursorItem->childCount()) + ")";
    QString curveStr = tr("Curves") + " (" + QString().setNum(curveItem->childCount()) + ")";
    triggerItem->setText(0, triggerStr);
    cursorItem->setText(0, cursorStr);
    curveItem->setText(0, curveStr);
    ui->viewTriggerCheck->setText(triggerStr);
    ui->viewCursorCheck->setText(cursorStr);
    ui->viewCurveCheck->setText(curveStr);
    ui->viewGroupLabel->setText(tr("Groups") + " (" + QString().setNum(ui->viewGroupCheckList->topLevelItemCount()) + ")");

    actionInfoLock = true;

    quint16 counterTriggers = 0, counterCurves = 0, counterCursors = 0, counterCursorsCurve = 0;

    if(render) {
        QList<NxObject*> *objects = render->getSelection();
        NxObject *objectsHover = 0;
        if((objects->count() == 0) && (render->getSelectedHover()))
            objectsHover = render->getSelectedHover();
        NxCursor *prevCursor = 0;
        NxTrigger *prevTrigger = 0;
        NxObject *prevObject = 0;
        NxCurve *prevCurve = 0;

        ui->colorCombo1->clear();
        ui->colorCombo2->clear();
        ui->colorCombo3->clear();
        ui->colorCombo4->clear();
        colorComboAdd(ui->colorCombo1, render->getRenderOptions()->colors.keys());
        colorComboAdd(ui->colorCombo2, render->getRenderOptions()->colors.keys());
        colorComboAdd(ui->colorCombo3, render->getRenderOptions()->colors.keys());
        colorComboAdd(ui->colorCombo4, render->getRenderOptions()->colors.keys());
        colorComboAdd(ui->colorCombo1, QStringList() << "Custom");
        colorComboAdd(ui->colorCombo2, QStringList() << "Custom");
        colorComboAdd(ui->colorCombo3, QStringList() << "Custom");
        colorComboAdd(ui->colorCombo4, QStringList() << "Custom");

        for(quint16 indexObject = 0 ; indexObject < objects->count()+1 ; indexObject++) {
            NxObject *object = 0;
            if(indexObject == objects->count())
                object = objectsHover;
            else
                object = objects->at(indexObject);
            if(!object)
                continue;

            if(prevObject == 0)
                prevObject = object;

            if(object->getType() == ObjectsTypeCursor)
                counterCursors++;
            else if(object->getType() == ObjectsTypeCurve)
                counterCurves++;
            else if(object->getType() == ObjectsTypeTrigger)
                counterTriggers++;

            if((object->getType() == ObjectsTypeCursor) && (((NxCursor*)object)->getCurve()))
                counterCursorsCurve++;

            change(indexObject, ui->IDSpin, object->getId(), prevObject->getId());
            change(indexObject, ui->groupIdButton, object->getGroupId() + tr(" (change)"), prevObject->getGroupId() + tr(" (change)"));
            change(indexObject, ui->positionX, object->getPos().x(), prevObject->getPos().x());
            change(indexObject, ui->positionY, object->getPos().y(), prevObject->getPos().y());
            change(indexObject, ui->positionZ, object->getZ(), prevObject->getZ());
            change(indexObject, ui->activityCheck, object->getActive(), prevObject->getActive());
            change(indexObject, ui->labelLine, object->getLabel(), prevObject->getLabel());
            change(indexObject, ui->colorCombo1, object->getColorActiveVerbose(), prevObject->getColorActiveVerbose());
            change(indexObject, ui->colorCombo2, object->getColorInactiveVerbose(), prevObject->getColorInactiveVerbose());
            change(indexObject, ui->sizeSpin, object->getSize(), prevObject->getSize());

            if(object->getType() == ObjectsTypeCursor) {
                NxCursor *cursor = (NxCursor*)object;
                if(prevCursor == 0)
                    prevCursor = cursor;

                change(indexObject, ui->widthSpin, cursor->getWidth(), prevCursor->getWidth());
                change(indexObject, ui->patternLine, cursor->getStart(), prevCursor->getStart());
                change(indexObject, ui->speedSpin, cursor->getTimeFactor(), prevCursor->getTimeFactor());
                change(indexObject, ui->speedFSpin, cursor->getTimeFactorF(), prevCursor->getTimeFactorF());
                change(indexObject, ui->offsetInitialSpin, cursor->getTimeInitialOffset(), prevCursor->getTimeInitialOffset());
                change(indexObject, ui->offsetStartSpin, cursor->getTimeStartOffset(), prevCursor->getTimeStartOffset());
                change(indexObject, ui->offsetEndSpin, cursor->getTimeEndOffset(), prevCursor->getTimeEndOffset());
                change(indexObject, ui->cursorBoundsLine1, cursor->getBoundsSource(), prevCursor->getBoundsSource());
                change(indexObject, ui->cursorBoundsLine2, cursor->getBoundsTarget(), prevCursor->getBoundsTarget());

                if(cursor->getCurve()) {
                    ui->posSpin->setValue(cursor->getCurrentPosition());
                    //ui->cursorPosLabel->setText(tr("Cursor Speed/Length") + "\r\n(" + QString().setNum(cursor->getCurrentPosition(), 'f', 3) + "s.)");
                    change(indexObject, ui->speedSpin, cursor->getTimeFactor(), prevCursor->getTimeFactor());
                    change(indexObject, ui->cursorLengthSpin, cursor->getCurve()->getPathLength() / cursor->getTimeFactor(), prevCursor->getCurve()->getPathLength() / prevCursor->getTimeFactor());
                }
                prevCursor = cursor;
            }
            else if(object->getType() == ObjectsTypeCurve) {
                NxCurve *curve = (NxCurve*)object;
                if(prevCurve == 0)
                    prevCurve = curve;

                change(indexObject, ui->sizeWSpin, curve->getResize().width(), prevCurve->getResize().width());
                change(indexObject, ui->sizeHSpin, curve->getResize().height(), prevCurve->getResize().height());
                prevCurve = curve;
            }
            else if(object->getType() == ObjectsTypeTrigger) {
                NxTrigger *trigger = (NxTrigger*)object;
                if(prevTrigger == 0)
                    prevTrigger = trigger;

                change(indexObject, ui->triggerOffSpin, trigger->getTriggerOff(), prevTrigger->getTriggerOff());
                change(indexObject, ui->colorCombo3, trigger->getColorActiveMessageVerbose(), prevTrigger->getColorActiveMessageVerbose());
                change(indexObject, ui->colorCombo4, trigger->getColorInactiveMessageVerbose(), prevTrigger->getColorInactiveMessageVerbose());
                prevTrigger = trigger;
            }
            prevObject = object;
        }
    }
    ui->typeLabel->setText("");
    if(counterTriggers == 1)
        ui->typeLabel->setText(ui->typeLabel->text() + " " + QString().setNum(counterTriggers) + " " + tr("trigger"));
    else if(counterTriggers > 1)
        ui->typeLabel->setText(ui->typeLabel->text() + " " + QString().setNum(counterTriggers) + " " + tr("triggers"));
    if(counterCurves == 1)
        ui->typeLabel->setText(ui->typeLabel->text() + " " + QString().setNum(counterCurves) + " " + tr("curve"));
    else if(counterCurves > 1)
        ui->typeLabel->setText(ui->typeLabel->text() + " " + QString().setNum(counterCurves) + " " + tr("curves"));
    if(counterCursors == 1)
        ui->typeLabel->setText(ui->typeLabel->text() + " " + QString().setNum(counterCursors) + " " + tr("cursor"));
    else if(counterCursors > 1)
        ui->typeLabel->setText(ui->typeLabel->text() + " " + QString().setNum(counterCursors) + " " + tr("cursors"));

    bool showCursorInfo = false, showTriggerInfo = false, showCurveInfo = false, showCursorCurveInfo = false, showGenericInfo = false;
    if(counterCurves > 0)
        showCurveInfo = true;
    if(counterCursors > 0)
        showCursorInfo = true;
    if(counterTriggers > 0)
        showTriggerInfo = true;
    if(counterCursorsCurve > 0)
        showCursorCurveInfo = true;
    if((counterCursors + counterCurves + counterTriggers) > 0)
        showGenericInfo = true;

    ui->labelSelection->setVisible(!showGenericInfo);
    ui->separator1->setVisible(showCursorInfo | showTriggerInfo);

    ui->IDSpin->setVisible(showGenericInfo);
    ui->IDLabel->setVisible(showGenericInfo);
    ui->groupIdButton->setVisible(showGenericInfo);
    ui->positionX->setVisible(showCurveInfo | showTriggerInfo);
    ui->positionY->setVisible(showCurveInfo | showTriggerInfo);
    ui->positionZ->setVisible(showCurveInfo | showTriggerInfo);
    ui->positionLabel->setVisible(showCurveInfo | showTriggerInfo);
    ui->activityCheck->setVisible(showGenericInfo);
    ui->activityLabel->setVisible(showGenericInfo);
    ui->messagesButton->setVisible(showGenericInfo);
    ui->messagesLabel->setVisible(showGenericInfo);
    ui->sizeSpin->setVisible(showGenericInfo);
    ui->sizeLabel2->setVisible(showGenericInfo);
    ui->labelLabel->setVisible(showGenericInfo);
    ui->labelLine->setVisible(showGenericInfo);
    ui->colorLabel->setVisible(showGenericInfo);
    ui->colorCombo1->setVisible(showGenericInfo);
    ui->colorCombo2->setVisible(showGenericInfo);

    ui->widthSpin->setVisible(showCursorInfo);
    ui->widthLabel->setVisible(showCursorInfo);
    ui->patternLine->setVisible(showCursorInfo);
    ui->patternLabel->setVisible(showCursorInfo);
    ui->speedSpin->setVisible(showCursorCurveInfo);
    ui->offsetInitialSpin->setVisible(showCursorCurveInfo);
    ui->offsetStartSpin->setVisible(showCursorCurveInfo);
    ui->offsetEndSpin->setVisible(showCursorCurveInfo);
    ui->offsetLabel->setVisible(showCursorCurveInfo);
    ui->offsetLabel1->setVisible(showCursorCurveInfo);
    ui->offsetLabel2->setVisible(showCursorCurveInfo);
    ui->offsetLabel3->setVisible(showCursorCurveInfo);
    ui->cursorLengthSpin->setVisible(showCursorCurveInfo);
    ui->cursorSpeedLabel->setVisible(showCursorCurveInfo);
    ui->posLabel->setVisible(showCursorCurveInfo);
    ui->posSpin->setVisible(showCursorCurveInfo);
    ui->cursorPosLabel2->setVisible(showCursorCurveInfo);
    ui->cursorBoundsLabel->setVisible(showCursorCurveInfo);
    ui->cursorBoundsLabel1->setVisible(showCursorCurveInfo);
    ui->cursorBoundsLabel2->setVisible(showCursorCurveInfo);
    ui->speedFLabel->setVisible(showCursorCurveInfo);
    ui->speedFSpin->setVisible(showCursorCurveInfo);
    ui->cursorBoundsLine1->setVisible(showCursorCurveInfo);
    ui->cursorBoundsLine2->setVisible(showCursorCurveInfo);

    ui->triggerOffLabel->setVisible(showTriggerInfo);
    ui->triggerOffSpin->setVisible(showTriggerInfo);
    ui->colorCombo3->setVisible(showTriggerInfo);
    ui->colorCombo4->setVisible(showTriggerInfo);

    ui->sizeHSpin->setVisible(showCurveInfo);
    ui->sizeWSpin->setVisible(showCurveInfo);
    ui->sizeLabel->setVisible(showCurveInfo);

    ui->messagesButton->setVisible(showCursorInfo | showTriggerInfo);
    ui->messagesLabel->setVisible(showCursorInfo | showTriggerInfo);

    needRefresh = false;
    actionInfoLock = false;
}
void UiInspector::change(quint16 indexObject, QDoubleSpinBox *spin, qreal val, qreal prevVal) {
    if(indexObject == 0) {
        spin->setStyleSheet("");
        spin->setValue(val);
    }
    else if((spin->styleSheet() == "") && (prevVal != val)) {
        spin->setStyleSheet("color: gray;");
    }
}
void UiInspector::change(quint16 indexObject, QSpinBox *spin, qint32 val, qint32 prevVal) {
    if(indexObject == 0) {
        spin->setStyleSheet("");
        spin->setValue(val);
    }
    else if((spin->styleSheet() == "") && (prevVal != val)) {
        spin->setStyleSheet("color: gray;");
    }
}
void UiInspector::change(quint16 indexObject, QPushButton *spin, const QString & val, const QString & prevVal) {
    if(indexObject == 0) {
        spin->setStyleSheet("");
        spin->setText(val);
    }
    else if((spin->styleSheet() == "") && (prevVal != val)) {
        spin->setStyleSheet("color: gray;");
    }
}
void UiInspector::change(quint16 indexObject, QCheckBox *spin, quint8 val, quint8 prevVal) {
    if(indexObject == 0) {
        spin->setStyleSheet("");
        spin->setChecked(val);
    }
    else if((spin->styleSheet() == "") && (prevVal != val)) {
        spin->setStyleSheet("QCheckBox::indicator { background-color: rgba(50, 237, 255, 128); }");
    }
}
void UiInspector::change(quint16 indexObject, QLineEdit *spin, const QString & val, const QString & prevVal) {
    if(indexObject == 0) {
        spin->setStyleSheet("");
        spin->setText(val);
    }
    else if((spin->styleSheet() == "") && (prevVal != val)) {
        spin->setStyleSheet("QCheckBox::indicator { background-color: rgba(50, 237, 255, 128); }");
    }
}
void UiInspector::change(quint16 indexObject, QComboBox *spin, const QString & val, const QString & prevVal) {
    qint16 indexVal = spin->findText(val);
    if(indexVal < 0)
        colorComboAdd(spin, QStringList() << val);

    if(indexObject == 0) {
        spin->setStyleSheet("");
        spin->setCurrentIndex(spin->findText(val));
    }
    else if((spin->styleSheet() == "") && (prevVal != val)) {
        spin->setStyleSheet("");
        spin->setCurrentIndex(-1);
    }
}

void UiInspector::colorComboAdd(QComboBox *spin, QStringList values) {
    foreach(const QString & value, values) {
        QPixmap icon(32, 32);
        QColor color = Qt::gray;
        QStringList valueSplit = value.split(" ", QString::SkipEmptyParts);
        if(valueSplit.count() == 4)
            color = QColor(valueSplit[0].toUInt(), valueSplit[1].toUInt(), valueSplit[2].toUInt(), valueSplit[3].toUInt());
        else
            color = render->getRenderOptions()->colors.value(value);
        icon.fill(color);
        if(value != "Custom")
            spin->addItem(QIcon(icon), value);
        else
            spin->addItem(value);
    }
}

NxObject* UiInspector::getSelectedCCObject() const {
    if((ui->ccView->currentItem() != triggerItem) && (ui->ccView->currentItem() != cursorItem) && (ui->ccView->currentItem() != curveItem))
        return (NxObject*)ui->ccView->currentItem();
    else
        return 0;
}


quint16 UiInspector::getCurrentTab() const {
    return ui->tab->currentIndex();
}
void UiInspector::setCurrentTab(quint16 val) {
    ui->tab->setCurrentIndex(val);
}

bool UiInspector::getViewTriggerCheck() const {
    return ui->viewTriggerCheck->isChecked();
}
void UiInspector::setViewTriggerCheck(bool val) {
    ui->viewTriggerCheck->setChecked(val);
}

bool UiInspector::getViewCurveCheck() const {
    return ui->viewCurveCheck->isChecked();
}
void UiInspector::setViewCurveCheck(bool val) {
    ui->viewCurveCheck->setChecked(val);
}

bool UiInspector::getViewCursorCheck() const {
    return ui->viewCursorCheck->isChecked();
}
void UiInspector::setViewCursorCheck(bool val) {
    ui->viewCursorCheck->setChecked(val);
}

void UiInspector::setOSCOk(bool val) {
    if(val)
        ui->oscInPortSpin->setStyleSheet("background: qlineargradient(spread:reflect, x1:0, y1:0, x2:0, y2:1, stop:0 rgba(151, 209, 38, 255), stop:1 rgba(86, 170, 28, 255));");
    else
        ui->oscInPortSpin->setStyleSheet("background: qlineargradient(spread:reflect, x1:0, y1:0, x2:0, y2:1, stop:0 rgb(248, 31, 29), stop:1 rgb(179, 33, 32));");
}
void UiInspector::setUDPOk(bool val) {
    if(val)
        ui->udpInPortSpin->setStyleSheet("background: qlineargradient(spread:reflect, x1:0, y1:0, x2:0, y2:1, stop:0 rgba(151, 209, 38, 255), stop:1 rgba(86, 170, 28, 255));");
    else
        ui->udpInPortSpin->setStyleSheet("background: qlineargradient(spread:reflect, x1:0, y1:0, x2:0, y2:1, stop:0 rgb(248, 31, 29), stop:1 rgb(179, 33, 32));");
}
void UiInspector::setSerialOk(bool val) {
    if(val)
        ui->serialInPortEdit->setStyleSheet("background: qlineargradient(spread:reflect, x1:0, y1:0, x2:0, y2:1, stop:0 rgba(151, 209, 38, 255), stop:1 rgba(86, 170, 28, 255));");
    else
        ui->serialInPortEdit->setStyleSheet("background: qlineargradient(spread:reflect, x1:0, y1:0, x2:0, y2:1, stop:0 rgb(248, 31, 29), stop:1 rgb(179, 33, 32));");
}
void UiInspector::setOSCPort(quint16 port) {
    ui->oscInPortSpin->setValue(port);
}
void UiInspector::setUDPPort(quint16 port) {
    ui->udpInPortSpin->setValue(port);
}
void UiInspector::setSerialPort(const QString & port) {
    ui->serialInPortEdit->setText(port);
}

